.. _wvggz:

WvGGZ
#####

Peter C. Gotzsche heeft de Tweede Kamer op 29 maart 2016 geinformeerd over de dodelijkheid van psychiatrische medicijnen. 
De Tweede Kamer is dus op de hoogte dat het om gif gaat en niet om medicijnen. Ook de minister weet dat het hier om gif gaat, 
maar maakt de max. dosis bekend waarmee de stof geacht word niet giftig te zijn en geen schade aan de patient te brengen. 
Natuurlijk is het onzin dat een gif onder een bepaalde dosis niet meer giftig zou zijn. De bijsluiters tonen waar men risico 
op loopt door deze stoffen wel toe te dienen. Een behandelplan met elke dag risico voor de patient ook dat dat risico ook plaats
heeft.

Stemt het slachtoffer met de gif toediening in, dan is hij met de bijsluiter geinformeerd over de ziektes die hij krijgt door de door de minister zonder schade verklaarde dosis van het gif.
Weigert het slachtoffer in te stemmen met de gif toediening, dan is deze wet bedoelt om dat gedwongen wel te kunnen doen. 

De door Wet verplichte GGZ gebruikte (F)ACT methode geeft de mogelijkheid om
een door de rechter geaccordieerde toediening van gif mogelijk te maken:
Op basis van "aanzienlijk risico" betekent niet dat men zonder rechter
handeld, het is dat de rechter EERDER kan handelen. Het aantal mensen dat
hierdoor antipsychotica krijgt toegedient zal dus van 300.000 naar veel meer
dan dat stijgen als deze wet doorgang krijgt.

De zorg waar men op doelt is een lijst met strafbare misdrijven waar de rechter toestemming voor geeft onder zijn supervisie plaats te laten vinden.
Naast alle vrijheidsontnemingen is het feit dat men gif toedient een element aan de strafbare feiten hier gepleegd die niet word meegenomen in wat deze wet is.
Men dient gif toe en geen medicijn, daarom is het geen behandeling maar een
poging tot moord. Men kan ook strafbaar is de richting van mishandeling
gepleegd door toediening van voor het leven of de gezondheid zoeken, maar
dat spreekt over schadelijke stof, niet over dodelijk.

Men levert dus strafbare feiten i.p.v zorg, iets waarvoor de overheid zelf verplicht is om tegen op te treden.

| Antipsychotica zijn :ref:`gif <gif>`, toedienen van antipsychotica maakt dat de patient te maken krijgt met vergiftigings :ref:`symptomen <symptomen>`.

